==> webkitgtk-2.2.1.tar.xz: webkitgtk-2.2.1/Source/WebCore/rendering/style/StyleGridItemData.cpp <==
/*
 * Copyright (C) 2012 Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *     * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#include "config.h"
#include "StyleGridItemData.h"

#include "RenderStyle.h"

namespace WebCore {

StyleGridItemData::StyleGridItemData()
    : m_gridColumnStart(RenderStyle::initialGridPosition())
    , m_gridColumnEnd(RenderStyle::initialGridPosition())
    , m_gridRowStart(RenderStyle::initialGridPosition())
    , m_gridRowEnd(RenderStyle::initialGridPosition())
{
}

StyleGridItemData::StyleGridItemData(const StyleGridItemData& o)
    : RefCounted<StyleGridItemData>()
    , m_gridColumnStart(o.m_gridColumnStart)
    , m_gridColumnEnd(o.m_gridColumnEnd)
    , m_gridRowStart(o.m_gridRowStart)
    , m_gridRowEnd(o.m_gridRowEnd)
{
}

} // namespace WebCore

==> webkitgtk-2.6.5.tar.xz: webkitgtk-2.6.5/Source/WebCore/rendering/style/StyleGridItemData.cpp <==
/*
 * Copyright (C) 2012 Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *     * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#include "config.h"
#include "StyleGridItemData.h"

#if ENABLE(CSS_GRID_LAYOUT)

#include "RenderStyle.h"

namespace WebCore {

StyleGridItemData::StyleGridItemData()
    : m_gridColumnStart(RenderStyle::initialGridItemColumnStart())
    , m_gridColumnEnd(RenderStyle::initialGridItemColumnEnd())
    , m_gridRowStart(RenderStyle::initialGridItemRowStart())
    , m_gridRowEnd(RenderStyle::initialGridItemRowEnd())
{
}

inline StyleGridItemData::StyleGridItemData(const StyleGridItemData& o)
    : RefCounted<StyleGridItemData>()
    , m_gridColumnStart(o.m_gridColumnStart)
    , m_gridColumnEnd(o.m_gridColumnEnd)
    , m_gridRowStart(o.m_gridRowStart)
    , m_gridRowEnd(o.m_gridRowEnd)
{
}

PassRef<StyleGridItemData> StyleGridItemData::copy() const
{
    return adoptRef(*new StyleGridItemData(*this));
}

} // namespace WebCore

#endif /* ENABLE(CSS_GRID_LAYOUT) */
